@@ -3752,7 +3752,7 @@ const unsigned char cursor_pipette_mask[] =
 
 /* --------------------------------------------------- */
 
-const unsigned char cursor_autoraise_scanarea[] = 
+const unsigned char cursor_autoraise_scan_area[] = 
 {
    0xaa, 0x2a, 0xc1, 0x41, 0xe0, 0x03, 0x81, 0x40, 0x80, 0x00, 0x85, 0x50,
    0x86, 0x30, 0x7f, 0x7f, 0x86, 0x30, 0x85, 0x50, 0x80, 0x00, 0x81, 0x40,
@@ -3761,7 +3761,7 @@ const unsigned char cursor_autoraise_scanarea[] =
 
 /* --------------------------------------------------- */
 
-const unsigned char cursor_autoraise_scanarea_mask[] =
+const unsigned char cursor_autoraise_scan_area_mask[] =
 {
    0xea, 0x2b, 0xe1, 0x43, 0xf0, 0x07, 0xc1, 0x41, 0xc4, 0x11, 0xc7, 0x71,
    0xff, 0x7f, 0x7f, 0x7f, 0xff, 0x7f, 0xc7, 0x71, 0xc4, 0x11, 0xc1, 0x41,
